==> 0.2.4.tar.gz: example/test/main.dart <==
import 'package:material_x/material_x.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    mxStatusBar();
    return VerticalExample().mxMaterialApp(title: 'zeeshan');
  }
}

class VerticalExample extends StatefulWidget {
  @override
  _VerticalExampleState createState() => _VerticalExampleState();
}

class _VerticalExampleState extends State<VerticalExample> {
  @override
  Widget build(BuildContext context) {
    return animationItemBuilder(
      (index) {
        return VerticalItem(title: index.toString());
      },
      padding: EdgeInsets.symmetric(vertical: 8),
    ).mxlbAnimated(itemCount: 100).mxScaffold();
  }
}

class GridExample extends StatefulWidget {
  @override
  _GridExampleState createState() => _GridExampleState();
}

class _GridExampleState extends State<GridExample> {
  int itemsCount = 500;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
          child: animationItemBuilder(
                  (index) => HorizontalItem(title: index.toString()))
              .mxGridAnimated(
                  itemCount: 100,
                  gridDelegate: mxSGDWFCC(
                      crossAxisCount: 4,
                      crossAxisSpacing: 16,
                      mainAxisSpacing: 16))),
    );
  }
}

class SliverExample extends StatefulWidget {
  @override
  _SliverExampleState createState() => _SliverExampleState();
}

class _SliverExampleState extends State<SliverExample> {
  ScrollController _scrollController;

  @override
  void initState() {
    _scrollController = ScrollController();
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) => Scaffold(
        body: SafeArea(
          child: CustomScrollView(
            controller: _scrollController,
            slivers: <Widget>[
              animationItemBuilder(
                      (index) => VerticalItem(title: index.toString()),
                      padding: EdgeInsets.symmetric(vertical: 8))
                  .mxSliverList(controller: _scrollController, itemCount: 10)
                  .mxsp(EdgeInsets.all(10.0)),
              animationItemBuilder(
                (index) => HorizontalItem(title: index.toString()),
              )
                  .mxSliverGrid(
                      controller: _scrollController,
                      itemCount: 30,
                      gridDelegate: mxSGDWFCC(
                          crossAxisCount: 4,
                          crossAxisSpacing: 16.0,
                          mainAxisSpacing: 16.0))
                  .mxsp(EdgeInsets.all(10.0)),
            ],
          ),
        ),
      );
}

==> 0.3.0.tar.gz: example/test/main.dart <==
import 'package:example/example/GridViewAnimation.dart';
import 'package:material_x/material_x.dart';

void main() => runApp(MyApp());

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    mxStatusBar();
    return ExampleGridViewAnimation().mxMaterialApp(title: 'zeeshan');
  }
}

class VerticalExample extends StatefulWidget {
  @override
  _VerticalExampleState createState() => _VerticalExampleState();
}

class _VerticalExampleState extends State<VerticalExample> {
  @override
  Widget build(BuildContext context) {
    return animationItemBuilder(
      (index) {
        return VerticalItem(title: index.toString());
      },
      padding: EdgeInsets.symmetric(vertical: 8),
    ).mxlbAnimated(itemCount: 100).mxScaffold();
  }
}

class GridExample extends StatefulWidget {
  @override
  _GridExampleState createState() => _GridExampleState();
}

class _GridExampleState extends State<GridExample> {
  int itemsCount = 500;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
          child: animationItemBuilder(
                  (index) => HorizontalItem(title: index.toString()))
              .mxGridAnimated(
                  itemCount: 100,
                  gridDelegate: mxSGDWFCC(
                      crossAxisCount: 4,
                      crossAxisSpacing: 16,
                      mainAxisSpacing: 16))),
    );
  }
}

class SliverExample extends StatefulWidget {
  @override
  _SliverExampleState createState() => _SliverExampleState();
}

class _SliverExampleState extends State<SliverExample> {
  ScrollController _scrollController;

  @override
  void initState() {
    _scrollController = ScrollController();
    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) => Scaffold(
        body: SafeArea(
          child: CustomScrollView(
            controller: _scrollController,
            slivers: <Widget>[
              animationItemBuilder(
                      (index) => VerticalItem(title: index.toString()),
                      padding: EdgeInsets.symmetric(vertical: 8))
                  .mxSliverList(controller: _scrollController, itemCount: 10)
                  .mxsp(EdgeInsets.all(10.0)),
              animationItemBuilder(
                (index) => HorizontalItem(title: index.toString()),
              )
                  .mxSliverGrid(
                      controller: _scrollController,
                      itemCount: 30,
                      gridDelegate: mxSGDWFCC(
                          crossAxisCount: 4,
                          crossAxisSpacing: 16.0,
                          mainAxisSpacing: 16.0))
                  .mxsp(EdgeInsets.all(10.0)),
            ],
          ),
        ),
      );
}
